@@ -10,6 +10,7 @@ imageSetMaker::imageSetMaker(QWidget* parent) :
     ui(new Ui::imageSetMaker)
 {
     ui->setupUi(this);
+    this->setAttribute(Qt::WA_Maemo5StackedWindow);
 
     // Setup a few QLists with 4 items each
     for(i=0; i<4; i++) {
@@ -92,6 +93,9 @@ imageSetMaker::imageSetMaker(QWidget* parent) :
 
     connect(ui->visibChkbox, SIGNAL(clicked()),
             this, SLOT(updateSaveBtn()));
+
+    connect(ui->readBtn, SIGNAL(clicked()),
+            this, SLOT(createUpdtWin()));
 }
 
 imageSetMaker::~imageSetMaker() {
@@ -386,7 +390,7 @@ void imageSetMaker::createAboutDialog() {
     // Only create a new dialog if it hasn't been made yet
     if(aboutDialogExists == false) {
         aboutDialog = new QDialog(this);
-        aboutDialog->setWindowTitle("Image Set Maker 0.3-1" + tr(" for ") + "Nokia N900");
+        aboutDialog->setWindowTitle("Image Set Maker 0.3.2" + tr(" for ") + "Nokia N900");
 
         aboutIcon = new QLabel;
         aboutIcon->setPixmap(QPixmap(":/images/imagesetmaker.png"));
@@ -478,4 +482,11 @@ void imageSetMaker::resetScreen() {
     // saveBtn
     updateSaveBtn();
 }
+
+void imageSetMaker::createUpdtWin() {
+    updtWin = new updateWin(this);
+    updtWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+    updtWin->setAttribute(Qt::WA_DeleteOnClose);
+    updtWin->show();
+}
 //********* END imageSetMaker public slots *******************
