@@ -1,6 +1,9 @@
 #ifndef IMAGESETMAKER_H
 #define IMAGESETMAKER_H
 
+#include "updatewin.h"
+#include "ui_updatewin.h"
+
 #include <QMainWindow>
 #include <QLabel>
 #include <QDir>
@@ -118,6 +121,8 @@ private:
         QVBoxLayout* aboutLayoutV3;
         QHBoxLayout* aboutLayoutH;
 
+    updateWin* updtWin;
+
 public slots:
     // Slots for imgBtnPrev#, these slots open openImage()
     void clickedImgBtnPrev0();
@@ -143,6 +148,8 @@ public slots:
 
     // Empty everything
     void resetScreen();
+
+    void createUpdtWin();
 };
 
 #endif // IMAGESETMAKER_H
